/*
Copyright (c) 1998-2009 VIA Technologies, Inc. All Rights Reserved.
 
This PROPRIETARY SOURCE CODE contains proprietary information of VIA 
Technologies, Inc. (VIA); Contents of this file shall not be disclosed to any 3rd party, 
copied or duplicated in any form, in whole or in part without prior written consent of 
VIA.  THIS SOURCE CODE & ANY RELATED DOCUMENTATION 
(COLLECTIVELY SOFTWARE) ARE PROVIDED AS IS, WITH ALL FAULTS, & 
WITHOUT WARRANTY OF ANY KIND.  VIA DISCLAIMS ALL EXPRESS OR 
IMPLIED WARRANTIES.  USER ACKNOWLEDGES THAT PARTIES FOR ANY 
DAMAGES ARISING FROM USE OF SOFTWARE OR ITS DERIVATIVE, 
INCLUDING, W/O LIMITATION, LOSS OF USE, DATA OR PROFITS. USER
WHOLLY ASSUMES ALL RISK ARISING FROM USE & PERFORMANCE OF 
SOFTWARE
*/ 
 
#ifndef ETKAPI_BASE_H_
#define ETKAPI_BASE_H_

#ifdef linux
// base type
#ifndef ETK_ALL_BASE_TYPE
#define ETK_ALL_BASE_TYPE
typedef unsigned char	BYTE;
typedef unsigned short	WORD;
typedef unsigned long	DWORD;
typedef long long __int64;

typedef BYTE		UCHAR;
typedef WORD		USHORT;
typedef DWORD		ULONG;

typedef UCHAR 		*PUCHAR;
typedef USHORT 		*PUSHORT;
typedef ULONG 		*PULONG;
typedef void		*PVOID;

typedef char			TCHAR;

// both SDK & driver
#ifndef HANDLE
#define HANDLE PVOID
#endif

#ifndef	 HWND
#define HWND		DWORD
#endif

#define INVALID_HANDLE_VALUE	-1

#define _T(x)		x

#define _tcscpy		strcpy

#endif // #ifndef ETK_ALL_BASE_TYPE

#ifndef BOOL
#define BOOL DWORD
#endif

#ifndef FALSE
#define FALSE (0)
#endif

// same as windows
#ifndef TRUE
#define TRUE (1)
#endif

#endif // linux

#ifdef __cplusplus
extern "C" {
#endif

#ifdef linux
#include <sys/ioctl.h>
#include <string.h>
#include <errno.h>

#define SMARTETK_API

#else

#include <windows.h>

#ifdef SMARTETK_EXPORTS
#define SMARTETK_API __declspec(dllexport)
#else
#define SMARTETK_API __declspec(dllimport)
#endif

#endif

/************************************************************************
							Error Code
************************************************************************/
/**
 * @def ETK_S_OK
 * @brief  The function is success.
 */
#define ETK_S_OK						0
/**
 * @def ETK_S_EXTSMI_NOT_START
 * @brief  The external SMI function does not be started.
 */
#define ETK_S_EXTSMI_NOT_START		1000

/**
 * @def ETK_E_FAIL
 * @brief  The function fails.
 */
#define ETK_E_FAIL					-1000
/**
 * @def ETK_E_BOARD_NOT_SUPPORT
 * @brief  The board is not supported.
 */
#define ETK_E_BOARD_NOT_SUPPORT		-1001
/**
 * @def ETK_E_ALREADY_INITIALIZED
 * @brief  SmartEtk dll has been loaded.
 */
#define ETK_E_ALREADY_INITIALIZED	-1002

/**
 * @def ETK_E_INVALID_ARG
 * @brief  The arguments are invalid.
 */
#define ETK_E_INVALID_ARG			-1003

/**
 * @def ETK_E_OUT_OF_MEMORY
 * @brief  Out of memory.
 */
#define ETK_E_OUT_OF_MEMORY			-1004

/**
 * @def ETK_E_FUNC_NOT_SUPPORT
 * @brief  The function is not supported on this board.
 */
#define ETK_E_FUNC_NOT_SUPPORT		-1005

/**
 * @def ETK_E_HARDWARE_ERROR
 * @brief  Hardware error.
 */
#define ETK_E_HARDWARE_ERROR			-1006

/**
 * @def ETK_E_HARDWARE_ERROR
 * @brief  Hardware error.
 */
#define ETK_E_HARDWARE_BUSY			-1007

/**
 * initial the SmartEtk SDK, and the SDK loads the driver.
 * @param pszBoardName: a pointer to the detected board name.
 * @return   :
 * ETK_S_OK: The function is success.
 * ETK_E_ALREADY_INITIALIZED: Other application was already initialized.
 * ETK_E_BOARD_NOT_SUPPORT: The board is not supported.
 * ETK_E_FAIL: The function fails.
 * @see ETK_UnInitialize()
 */
SMARTETK_API DWORD ETK_Initialize(TCHAR * pszBoardName);

/**
 * release the SmartEtk SDK, and the SDK unloads the driver.
 * @return   : Returns TRUE if successful or FALSE otherwise.
 * @remarks  : You MUST BE SURE that ETK_UnInitialize() is called when the application is closed.
 *             Otherwise ETK_Initialize() cannot be normally called next time.
 */
SMARTETK_API BOOL ETK_UnInitialize(void);

/**
 * Get BIOS ID.
 * @param nBufSize: buffer size
 * @param pBiosId: a pointer to the detected BIOS ID.
 * @return   : Returns ETK_S_OK if successful or ETK_E_FAIL otherwise.
 */
SMARTETK_API DWORD ETK_GetBiosId(DWORD nBufSize, char* pBiosId);
/**
 * Get BIOS Date.
 * @param nBufSize: buffer size
 * @param pBiosDate: a pointer to the detected BIOS Date.
 * @return   : Returns ETK_S_OK if successful or ETK_E_FAIL otherwise.
 */
SMARTETK_API DWORD ETK_GetBiosDate(DWORD nBufSize, char* pBiosDate);
/**
 * Get BIOS Signon.
 * @param nBufSize: buffer size
 * @param pBiosSignon: a pointer to the detected BIOS Signon.
 * @return   : Returns ETK_S_OK if successful or ETK_E_FAIL otherwise.
 */
SMARTETK_API DWORD ETK_GetBiosSignon(DWORD nBufSize, char* pBiosSignon);
/**
 * Get ChipsetName.
 * @param nBufSize: buffer size
 * @param pChipsetName: a pointer to the detected ChipsetName.
 * @return   : Returns ETK_S_OK if successful or ETK_E_FAIL otherwise.
 */
SMARTETK_API DWORD ETK_GetChipsetName(DWORD nBufSize, char* pChipsetName);
/**
 * Get OEM Signon.
 * @param nBufSize: buffer size
 * @param pOEMSignon: a pointer to the detected OEM Signon.
 * @return   : Returns ETK_S_OK if successful or ETK_E_FAIL otherwise.
 */
SMARTETK_API DWORD ETK_GetOEMSignon(DWORD nBufSize, char* pOEMSignon);

#ifdef __cplusplus
} // extern C
#endif

#endif // ETKAPI_BASE_H_
